<?php
/*
Plugin Name: RSS Feed Signature 
Plugin URI: http://www.smackfoo.com/plugins/sig2feed/
Description: Add a customised signature or tag-line to your RSS feed(s). Enable then configure in <a href="edit.php?page=sig2feed.php">Manage -> RSS Signature</a>.
Author: Brendan Borlase
Version: 1.1
Author URI: http://www.smackfoo.com/
*/

/*

 Based on 'Add Sig' by Aleister - http://www.dagondesign.com

*/


// Setup defaults if options do not exist

add_option('sig2feed_data', '<p><center>&copy; %FIRST %LAST% - visit the <a href="%URL%">author</a> for more great content.</center></p>');	// Signature data
add_option('sig2feed_sfeed', FALSE);	// Disable RSS signature by default


function sig2feed_add_option_pages() {
	if (function_exists('add_options_page')) {
		add_management_page('Configure RSS Signature', 'RSS Signature', 8, __FILE__, 'sig2feed_options_page');
	}		
}

function sig2feed_trim_sig($sig) {
	return trim($sig, "*");
}


function sig2feed_options_page() {

	if (isset($_POST['info_update'])) {	?>
		
	<div id="message" class="updated fade"><p><strong><?php 
      update_option('sig2feed_data', '*' . (string)$_POST["sig2feed_data"] . '*');
      update_option('sig2feed_sfeed', (bool)$_POST["sig2feed_sfeed"]);
			echo "Configuration updated, booyah!"; ?>
			</strong></p>
		</div>
	<?php	 } ?>

	<div class=wrap>

    <h2>RSS Signature</h2>
	
    <p>RSS Signatute (sig2feed) will add the signature below to the <strong><?php bloginfo() ?></strong> main 
        RSS feed(s), to provide a custom tag-line, or direct readers back to your blog.</p>
    
    <p>If you wish to add post-by-post control, disable the feed below and insert 
        <code>&lt;!-- sig2feed --&gt;</code> in any post you wish to trigger sig2feed on.</p>
        
    <p><em>To check for new versions or view more information on use, please 
        visit the official <a href="http://www.smackfoo.com/plugins/sig2feed/">sig2feed plugin page</a>.</em></p>

    <form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
    <input type="hidden" name="info_update" id="info_update" value="true" />
  </div>
	
	<div class=wrap>
    <fieldset class="options"> 
      
      <h3>Signature</h3>

      <textarea name="sig2feed_data" cols="83" rows="6">
        <?php echo htmlspecialchars(stripslashes(sig2feed_trim_sig(get_option('sig2feed_data')))) ?>
      </textarea>
      <br /><br />
      <strong>Notes:</strong>
        <ul>
          <li>HTML is allowed <small>(note: use valid HTML as it will <em>not</em> be checked)</small></li>
          <li><strong>All</strong> newlines will be turned into line breaks</li>
          <li>CSS can be used to customise the look</li>
          <li>An example has been provided <small>(note: example is disabled by default)</small></li>
        </ul>	

      <strong>The following variables are available to simplify or customise the signature:</strong>
	
        <ul>
          <li>%LOGIN% - Login name</li>
          <li>%FIRST% - First name</li>
          <li>%LAST% - Last name</li>
          <li>%NICK% - Nickname</li>
          <li>%EMAIL% - Email address</li>
          <li>%URL% - Website</li>
          <li>%DESC% - Description/Bio</li>
        </ul>

      <fieldset class="options"> 
      <h3>Options</h3>
        <input type="checkbox" name="sig2feed_sfeed" value="checkbox" <?php if (get_option('sig2feed_sfeed')) echo "checked='checked'"; ?>/>
          &nbsp;&nbsp;
        <strong>Enable custom RSS Signature and display in RSS feeds?</strong>

      <div class="submit">
        <input type="submit" name="info_update" value="<?php _e('Update options'); ?> &raquo;" />
      </div>
  </div>

  <div class='wrap'>
    <p>If you found sig2feed useful, please do consider 
      <a href="https://www.paypal.com.au/cgi-bin/webscr?cmd=_xclick&business=yanis%40angrymonkeys%2enet&item_name=wordpress plugin development&no_shipping=2&no_note=1&currency_code=AUD&bn=PP%2dDonationsBF&charset=UTF%2d8" target="_blank">making a donation</a> 
      to support it's development. Thank you!</p>
    </fieldset>
	</form>
	</div>
	
<?php
  }

  function sig2feed_generate($content) {

    global $wpdb, $table_prefix, $id, $authordata;

    // Load options
      $sig2feed_data = get_option('sig2feed_data');
      $sig2feed_sfeed = get_option('sig2feed_sfeed');
	
    // Check page type
      $show_sig = FALSE;
      
      if((is_feed() || $doing_rss) && $sig2feed_sfeed) {
        $show_sig = TRUE;
      }
	
      $found = strpos ($content, '<!-- sig2feed -->');

      if ($found) {
        $show_sig = TRUE;
      }

      if (!$show_sig) {
        return $content;
      }

    // Get author information
      $a_login = get_the_author_login();		// %LOGIN%
      $a_first = get_the_author_firstname();	// %FIRST% 
      $a_last = get_the_author_lastname();	// %LAST%
      $a_nick = get_the_author_nickname(); 	// %NICK%
      $a_email = get_the_author_email(); 		// %EMAIL%
      $a_url = get_the_author_url();			// %URL%
      $a_desc = get_the_author_description();	// %DESC%
  
    // Process signature
      $the_sig = stripslashes(nl2br(sig2feed_trim_sig($sig2feed_data)));
      $the_sig = str_replace("%LOGIN%", $a_login, $the_sig);
      $the_sig = str_replace("%FIRST%", $a_first, $the_sig);
      $the_sig = str_replace("%LAST%", $a_last, $the_sig);
      $the_sig = str_replace("%NICK%", $a_nick, $the_sig);
      $the_sig = str_replace("%EMAIL%", $a_email, $the_sig);
      $the_sig = str_replace("%URL%", $a_url, $the_sig);
      $the_sig = str_replace("%DESC%", $a_desc, $the_sig);

    // Look for trigger
      if ($found_trigger) { 			// If trigger found, process
        $content = str_replace('<!-- sig2feed -->', $the_sig, $content);
      } else {	
        $content .= $the_sig;
    }

  return $content;

}

  add_filter('the_content', 'sig2feed_generate');
  add_action('admin_menu', 'sig2feed_add_option_pages');

?>